@@ -152,8 +152,8 @@ func (c *Config) runChattrCmd(cmd *cobra.Command, args []string, sourceState *ch
 	}
 
 	targetRelPaths, err := c.targetRelPaths(sourceState, args[1:], targetRelPathsOptions{
-		mustBeInSourceState: true,
-		recursive:           c.chattr.recursive,
+		mustBeManaged: true,
+		recursive:     c.chattr.recursive,
 	})
 	if err != nil {
 		return err
