@@ -569,8 +569,8 @@ func (c *Config) applyArgs(
 		}
 	default:
 		targetRelPaths, err = c.targetRelPaths(sourceState, args, targetRelPathsOptions{
-			mustBeInSourceState: true,
-			recursive:           options.recursive,
+			mustBeManaged: true,
+			recursive:     options.recursive,
 		})
 		if err != nil {
 			return err
@@ -665,6 +665,16 @@ func (c *Config) colorAutoFunc() bool {
 // createAndReloadConfigFile creates a config file if it there is a config file
 // template and reloads it.
 func (c *Config) createAndReloadConfigFile(cmd *cobra.Command) error {
+	// Refresh the source directory, as there might be a .chezmoiroot file and
+	// the template data is set before .chezmoiroot is read.
+	sourceDirAbsPath, err := c.getSourceDirAbsPath(&getSourceDirAbsPathOptions{
+		refresh: true,
+	})
+	if err != nil {
+		return err
+	}
+	c.templateData.sourceDir = sourceDirAbsPath
+
 	// Find config template, execute it, and create config file.
 	configTemplate, err := c.findConfigTemplate()
 	if err != nil {
@@ -2202,6 +2212,7 @@ func (c *Config) setEncryption() error {
 func (c *Config) sourceAbsPaths(sourceState *chezmoi.SourceState, args []string) ([]chezmoi.AbsPath, error) {
 	targetRelPaths, err := c.targetRelPaths(sourceState, args, targetRelPathsOptions{
 		mustBeInSourceState: true,
+		mustBeManaged:       true,
 	})
 	if err != nil {
 		return nil, err
@@ -2225,6 +2236,7 @@ func (c *Config) targetRelPath(absPath chezmoi.AbsPath) (chezmoi.RelPath, error)
 
 type targetRelPathsOptions struct {
 	mustBeInSourceState bool
+	mustBeManaged       bool
 	recursive           bool
 }
 
@@ -2243,8 +2255,12 @@ func (c *Config) targetRelPaths(
 		if err != nil {
 			return nil, err
 		}
+		sourceStateEntry := sourceState.Get(targetRelPath)
+		if options.mustBeManaged && sourceStateEntry == nil {
+			return nil, fmt.Errorf("%s: not managed", arg)
+		}
 		if options.mustBeInSourceState {
-			if sourceState.Get(targetRelPath) == nil {
+			if _, ok := sourceStateEntry.(*chezmoi.SourceStateRemove); ok {
 				return nil, fmt.Errorf("%s: not in source state", arg)
 			}
 		}
